This is a fork of Google/DeepMind's Hanabi Learning Environment. We created it because we needed it released on PyPI, and they wouldn't.

To install it, use `pip3 install hanabi_learning_environment`.

If anyone at Google/DeepMind would like to finally upstream this so we aren't maintaining our own fork, please let us know.
